@@ -20,11 +20,19 @@ def pytest_runtest_makereport(item, call):
     outcome = yield
     report = outcome.get_result()
     extra = getattr(report, "extra", [])
-    if screenshot_option == "all" or "failonly":
-        if report.when == "call":
-            extra.append(extras.image(item.module.gif_file, mime_type='image/gif', extension='gif'))
-            report.extra = extra
-    else:
+    screenshot = item.config.option.screenshot
+
+    if report.when == 'call':
+        if not (screenshot == 'failonly' and report.outcome == 'passed'):
+            # item.module.test_obj.gif_file_name
+            f_name = None
+            if item.config.option.bdd_flag == 'Y':
+                f_name = item.module.test_obj.gif_file_name
+            elif 'test_obj' in item.funcargs and item.funcargs['test_obj'].gif_file_name:
+                f_name = item.funcargs['test_obj'].gif_file_name
+
+            if f_name:
+                extra.append(extras.image(f_name, mime_type='image/gif', extension='gif'))
         report.extra = extra
 
 
@@ -420,10 +428,10 @@ def pytest_addoption(parser):
                          dest="non_breakable",
                          default='N',
                          help="Determine when failure happen, the flow will break or not: Y or N")
-        parser.addoption("--bdd_flag",
-                         dest="bdd_flag",
-                         default="N",
-                         help="Determine if the run is in BDD: Y or N")
+        # parser.addoption("--bdd_flag",
+        #                  dest="bdd_flag",
+        #                  default="N",
+        #                  help="Determine if the run is in BDD: Y or N")
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
