@@ -5,6 +5,8 @@ Class to hold miscellaneous but useful decorators for our framework
 from inspect import getfullargspec
 import traceback
 
+import pytest_html
+
 
 class Wrapit():
     "Wrapit class to hold decorator functions"
@@ -55,25 +57,25 @@ class Wrapit():
 
         return wrapper
 
-    # def _logging_decorator(func):
-    #
-    #     def wrapper(test_obj, product, cases, extra, testID, *args, **kwargs):
-    #         try:
-    #             result = func(test_obj, product, cases, extra, testID, *args, **kwargs)
-    #             globals()['gif_file'] = test_obj.write_test_summary()
-    #         except Exception as e:
-    #             print("Exception when trying to run test: %s" % __file__)
-    #             print("Python says:%s" % str(e))
-    #             test_obj.write(traceback.format_exc())
-    #
-    #             # Detail print in last line
-    #             with open(test_obj.logs_parent_dir + test_obj.log_name, "a") as logfile:
-    #                 traceback.print_exc(file=logfile)
-    #             globals()['gif_file'] = test_obj.write_test_summary()
-    #             raise
-    #         return result
-    #
-    #     return wrapper
+    def _logging_decorator(func):
+
+        def wrapper(test_obj, product, cases, extra, testID, *args, **kwargs):
+            try:
+                result = func(test_obj, product, cases, extra, testID, *args, **kwargs)
+                test_obj.gif_file_name = test_obj.write_test_summary()
+            except Exception as e:
+                print("Exception when trying to run test: %s" % __file__)
+                print("Python says:%s" % str(e))
+                test_obj.write(traceback.format_exc())
+
+                # Detail print in last line
+                with open(test_obj.logs_parent_dir + test_obj.log_name, "a") as logfile:
+                    traceback.print_exc(file=logfile)
+                globals()['gif_file'] = test_obj.write_test_summary()
+                raise
+            return result
+
+        return wrapper
 
     def _check_browser_console_log(func):
         "Decorator to check the browser's console log for errors"
